@@ -5,6 +5,8 @@ import pandas as pd
 import re
 from scipy.sparse import hstack, csr_matrix
 import numpy as np
+import warnings
+warnings.filterwarnings("ignore")
 class isitkbs(object):
     
     def __init__(self, model='randomforest'):
@@ -255,9 +257,4 @@ class aux(object):
             if cls.__repeticao_de_bigramas(cls, string, length): return 1
             if cls.__bigramas_proibidos(cls, string): return 1
         except:
-            return 0
-
-
-teste = isitkbs()
-
-print(teste.sentkbs("I amerwefsxx Sidney"))
\ No newline at end of file
+            return 0
\ No newline at end of file
